@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated matches, removed certainty and updated version detection
-##
-Plugin.define "boastMachine" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-16
+Plugin.define do
+name "boastMachine"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-16
+  # v0.2 # Updated matches, removed certainty and updated version detection. 
+]
 version "0.2"
 description "boastMachine blog"
 website "http://boastology.com/"
