@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Cisco-Adaptive-Security-Appliance" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-11
+Plugin.define do
+name "Cisco-Adaptive-Security-Appliance"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-11
+]
 version "0.1"
 description "The Cisco Adaptive Security Appliance (ASA) family of security devices protects corporate networks. It provides users with highly secure access to data - anytime, anywhere, using any device."
 website "http://www.cisco.com/web/ANZ/products/security/asa_software.html"
