@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Citrix-XenServer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-28
+Plugin.define do
+name "Citrix-XenServer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-28
+]
 version "0.1"
 description "Citrix XenServer is a complete, managed server virtualization platform built on the powerful Xen hypervisor."
 website "http://www.citrix.com/English/ps2/products/feature.asp?contentID=2300351"
