@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Dolphin" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-05
+Plugin.define do
+name "Dolphin"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-05
+]
 version "0.1"
 description "Dolphin is built using PHP and MySQL running on Apache. It is tested and proven stable running on Linux. Dolphin will also run on Windows if needed."
 website "http://www.busmgtsys.com/"
