@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Dr-Web-Anti-Virus" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-07-31
+Plugin.define do
+name "Dr-Web-Anti-Virus"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-07-31
+]
 version "0.1"
 description "Dr.Web anti-virus"
 website "http://www.drweb.com/"
