@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ECShop" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-18
+Plugin.define do
+name "ECShop"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-18
+]
 version "0.1"
 description "Ecshop is an Open Source Ecommerce Platform"
 website "http://www.ecshop.org/"
