@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated matches and version detection
-##
-Plugin.define "F3Site" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-27
+Plugin.define do
+name "F3Site"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-27
+  # v0.2 # Updated matches and version detection. 
+]
 version "0.2"
 description "F3Site is a lightweight CMS written in XHTML 1.0 Strict, CSS and PHP 5. It lets you create multilingual websites without necessity of separate installation for each language."
 website "http://compmaster.prv.pl"
