@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "GpsGate-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-20
+Plugin.define do
+name "GpsGate-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-20
+]
 version "0.1"
 description "GpsGate Server is a platform for web based GPS tracking of vehicles, valuable assets and persons. The modular GpsGate Server platform also allows you to configure, extend and customize applications to your needs."
 website "http://gpsgate.com/products/gpsgate_server"
