@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "H3C-SecBlade-FireWall" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-12
+Plugin.define do
+name "H3C-SecBlade-FireWall"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-12
+]
 version "0.1"
 description "H3C SecBlade FireWall modules are industry-leading 10000-Mbps high-performance firewall modules"
 website "http://www.h3c.com/portal/Products___Solutions/Products/Security_Products/H3C_SecBlade_Module/H3C_SecBlade_FW/"
