@@ -2,16 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.3 # 2016-04-20 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-# Version 0.2 # 2011-01-25 #
-# Updated version detection
-##
-Plugin.define "IBM-HTTP-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-25
+Plugin.define do
+name "IBM-HTTP-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-25
+  # v0.2 # 2011-01-25 # Updated version detection. 
+  "Andrew Horton", # v0.3 # 2016-04-20 # Moved patterns from passive function to matches[]. 
+]
 version "0.3"
 description "IBM HTTP Server is based on the Apache HTTP Server (httpd.apache.org), developed by the Apache Software Foundation. IBM HTTP Server can be remotely administered and configured using the WebSphere administrative console"
 website "http://www.ibm.com/software/webservers/httpservers/"
