@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Kerio-WinRoute-Firewall" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-05-11
+Plugin.define do
+name "Kerio-WinRoute-Firewall"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-05-11
+]
 version "0.1"
 description "Kerio WinRoute Firewall"
 website "http://winroute.ru/kerio_winroute_firewall.htm"
