@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "LaserWash" do
-author "Brendan Coles <bcoles@gmail.com>" # 2013-07-28
+Plugin.define do
+name "LaserWash"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2013-07-28
+]
 version "0.1"
 description "PDQ - LaserWash - touchless car wash equipment."
 website "http://www.pdqinc.com/car-wash-equipment/laserwash-360.asp"
