@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "OpenConf" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-05-03
+Plugin.define do
+name "OpenConf"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-05-03
+]
 version "0.1"
 description "OpenConf is an abstract and peer-review management system that greatly facilitates the submission and review processes for conferences, workshops, and symposia."
 website "http://www.openconf.com/"
