@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Pligg-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-11
+Plugin.define do
+name "Pligg-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-11
+]
 version "0.1"
 description "Pligg is an open source CMS (Content Management System) that you can download and use for free."
 website "http://www.pligg.com/"
