@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "RaidenHTTPD" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-16
+Plugin.define do
+name "RaidenHTTPD"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-16
+]
 version "0.1"
 description "RaidenHTTPD is a fully featured web server software for Windows platform."
 website "http://www.raidenhttpd.com/en/"
