@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ReOS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-02-04
+Plugin.define do
+name "ReOS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-02-04
+]
 version "0.1"
 description "REOS is hi-end software solution designed to help real estate agents, brokers and offices to easily present their properties on the internet."
 website "http://www.reosonline.com/"
