@@ -2,16 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.3 # 2011-03-23 #
-# Removed aggressive section
-##
-# Version 0.2 #
-# Added aggressive `/robots.txt` retrieval
-##
-Plugin.define "robots_txt" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-22
+Plugin.define do
+name "robots_txt"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-22
+  # v0.2 # Added aggressive `/robots.txt` retrieval. 
+  # v0.3 # 2011-03-23 # Removed aggressive section. 
+]
 version "0.3"
 description "This plugin identifies robots.txt files and extracts both allowed and disallowed directories. - More Info: http://www.robotstxt.org/"
 
@@ -21,7 +20,7 @@ description "This plugin identifies robots.txt files and extracts both allowed a
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Extract directories if current file is robots.txt
