@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SDL-Tridion-WCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-20
+Plugin.define do
+name "SDL-Tridion-WCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-20
+]
 version "0.1"
 description "SDL Tridion WCMS - Web Content Management System (WCMS)"
 website "http://www.sdl.com/en/wcm/products/sdltridion/default.asp"
