@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "vTigerCRM" do
-author "Aung Khant <http://yehg.net/>" # 2011-02-04
+Plugin.define do
+name "vTigerCRM"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2011-02-04
+]
 version "0.1"
 description "vTigerCRM - http://www.vtiger.com/"
 
