@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "WANem" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-09-08
+Plugin.define do
+name "WANem"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-09-08
+]
 version "0.1"
 description "WANem is a Wide Area Network emulator designed by Performance Engineering Research Centre, TATA Consultancy Services, Mumbai."
 website "http://wanem.sourceforge.net/"
