@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "WebIssues" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-29
+Plugin.define do
+name "WebIssues"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-29
+]
 version "0.1"
 description "WebIssues is an open source, multi-platform system for issue tracking and team collaboration."
 website "http://webissues.mimec.org/"
