@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "WWWPhoto" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-01-29
+Plugin.define do
+name "WWWPhoto"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-01-29
+]
 version "0.1"
 description "WWWPhoto is a tag based web photo gallery for PHP5 with GD-Library and MySQL or PostgreSQL. Since release 0.1.0 the navigation on the user view is Ajax driven by using the JSON implementation for PHP from Michal Migurski, Matt Knapp and Brett Stimmerman (http://pear.php.net/pepr/pepr-proposal-show.php?id=198)"
 website "http://www.pburkhalter.net/wwwphoto.php"
